declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                firstName: import("zod").ZodString;
                lastName: import("zod").ZodString;
                organizations: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    name: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
    }[];
};
export default service;
//# sourceMappingURL=user.d.ts.map